# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from .guardrail_write_name import GuardrailWriteName
from .guardrail_write_result import GuardrailWriteResult
from .json_node import JsonNode
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class GuardrailWrite(UniversalBaseModel):
    entity_id: str
    secondary_id: str
    project_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    If null, the default project is used
    """

    name: GuardrailWriteName
    result: GuardrailWriteResult
    config: JsonNode
    details: JsonNode

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow", frozen=True
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
